#!/bin/bash -l
#SBATCH -J angsd_ABBABABA_multipop_REVISION_01
#SBATCH -o angsd_ABBABABA_multipop_REVISION_01_%j.out
#SBATCH -e angsd_ABBABABA_multipop_REVISION_01_%j.err
#SBATCH -t 12:00:00
#SBATCH -n 1
#SBATCH -c 4
#SBATCH --mem=64000
#SBATCH -p serial
#SBATCH --mail-type=END
#SBATCH --mail-user=tiina.mattila@oulu.fi

date

#Load dependencies
module load biokit
module load r-env
export PATH=${PATH}:${USERAPPL}/angsd_GIT2/angsd/
export PATH=${PATH}:${USERAPPL}/angsd_GIT2/angsd/misc/
REF=/wrk/mattitii/DONOTREMOVE/FINAL_ANALYSES/AL_REF/Arabidopsis_lyrata.v.1.0.29.dna.genome.fa

#Abba baba population test for ((SP, PL)STORR)MA, ((STU, PL)STORR)MA, ((STU, STORR)SP)MA

#Set path to sites (not needed if the sites files are in the working directory)
SITES=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/MASKS_010317/AL_1.0.29_4fold_globmasked_CHR.sites

##Set a file of chromosomes to include
REGIONS=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/SUPPORT_FILES/Chrom.txt

##Set angsd filtering settings
FILTER="-remove_bads -unique_only -minMapQ 30 -minQ 20 -only_proper_pairs 1 -trim 0"

BAM1=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/SUPPORT_FILES/SP_PL_STORR_MA_bam.filelist  
BAM2=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/SUPPORT_FILES/STU_PL_STORR_MA_bam.filelist
BAM3=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/SUPPORT_FILES/STU_STORR_SP_MA_bam.filelist

angsd $FILTER -minInd 19 -P 4 -out SP_PL_STORR_MA_abbababa2 -doAbbababa2 1 -bam $BAM1 -doCounts 1 -sample 0 -enhance 0 -blockSize 10000 -sizeH1 5 -sizeH2 6 -sizeH3 2 -sizeH4 6 -combFile 0 -rf $REGIONS -sites $SITES
angsd $FILTER -minInd 19 -P 4 -out STU_PL_STORR_MA_abbababa2 -doAbbababa2 1 -bam $BAM2 -doCounts 1 -sample 0 -enhance 0 -blockSize 10000 -sizeH1 5 -sizeH2 6 -sizeH3 2 -sizeH4 6 -combFile 0 -rf $REGIONS -sites $SITES
angsd $FILTER -minInd 18 -P 4 -out STU_STORR_SP_MA_abbababa2 -doAbbababa2 1 -bam $BAM3 -doCounts 1 -sample 0 -enhance 0 -blockSize 10000 -sizeH1 5 -sizeH2 2 -sizeH3 5 -sizeH4 6 -combFile 0 -rf $REGIONS -sites $SITES

#Calculate abbababa statistics
Rscript estAvgError.R angsdFile=SP_PL_STORR_MA_abbababa2 out=SP_PL_STORR_MA_abbababa2_outDstat
Rscript estAvgError.R angsdFile=STU_PL_STORR_MA_abbababa2 out=STU_PL_STORR_MA_abbababa2_outDstat
Rscript estAvgError.R angsdFile=STU_STORR_SP_MA_abbababa2 out=STU_STORR_SP_MA_abbababa2_outDstat

date


