#!/bin/bash -l
#SBATCH -J angsd_basic_folded_STU_REVISION_01
#SBATCH -o angsd_basic_folded_STU_REVISION_01_%j.out
#SBATCH -e angsd_basic_folded_STU_REVISION_01_%j.err
#SBATCH -t 20:00:00
#SBATCH -n 1
#SBATCH --nodes=1
#SBATCH --cpus-per-task=4
#SBATCH --mem=16000
#SBATCH -p serial
#SBATCH --array=1-4
#SBATCH --mail-type=END
#SBATCH --mail-user=tiina.mattila@oulu.fi

name=$(sed -n "$SLURM_ARRAY_TASK_ID"p /wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/SUPPORT_FILES/namelist_020317)

export PATH=${PATH}:${USERAPPL}/angsd_GIT2/angsd/
export PATH=${PATH}:${USERAPPL}/angsd_GIT2/angsd/misc/

#Set path to sites (not needed if the sites files are in the working directory)
SITEPATH=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/MASKS_010317/

#Set reference (ancestral) path
REF_AL=/wrk/mattitii/DONOTREMOVE/FINAL_ANALYSES/AL_REF/Arabidopsis_lyrata.v.1.0.29.dna.genome.fa

#name of the file containing list of full paths of bamfiles, one sample/row
STU=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/SUPPORT_FILES/STU_bam.filelist

##Set number of chromosomes
NCHR=5

##Set output name
OUTP=STU_${name::${#name}-6}

##Set sites filter file
SITES=$SITEPATH$name

##Set windowsize in bp
WIN=100000
WIN2=10000
WIN3=5000

##Set a file of chromosomes to include
REGIONS=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/SUPPORT_FILES/Chrom.txt

##Set angsd filtering settings
FILTER="-remove_bads -unique_only -minMapQ 30 -minQ 20 -only_proper_pairs 1 -trim 0 -minInd 4"

#Index sites files, done
#angsd sites index $SITES

##Calculate site allele frequency likelihoods (saf)
angsd -b $STU -anc $REF_AL $FILTER -out $OUTP -P 4 -GL 2 -doSaf 1 -sites $SITES -rf $REGIONS -fold 1

##Estimate allele frequency spectrum
realSFS $OUTP.saf.idx -P 4 -bootstrap 100 > "$OUTP"_bootstrap.sfs
realSFS $OUTP.saf.idx -P 4 > $OUTP.sfs

##Calculate thetas using the estimated sfs as a prior
angsd -bam $STU $FILTER -out "$OUTP"_theta -doSaf 1 -doThetas 1 -pest $OUTP.sfs -anc $REF_AL -GL 2 -P 4 -sites $SITES -rf $REGIONS -fold 1

#THETA NOT NEEDED FOR DEMOGRAPHY
#create a binary version of theta.thetas.gz
thetaStat make_bed "$OUTP"_theta.thetas.gz

#calculate statistics
thetaStat do_stat "$OUTP"_theta.thetas.gz -nChr $NCHR

#calculte window statistics, e.g. 100 KB non-overlapping windows
thetaStat do_stat "$OUTP"_theta.thetas.gz -nChr $NCHR -win $WIN -step $WIN -type 2 -outnames "$OUTP"_thetasWindows_$WIN.gz
thetaStat do_stat "$OUTP"_theta.thetas.gz -nChr $NCHR -win $WIN2 -step $WIN2 -type 2 -outnames "$OUTP"_thetasWindows_$WIN2.gz
thetaStat do_stat "$OUTP"_theta.thetas.gz -nChr $NCHR -win $WIN3 -step $WIN3 -type 2 -outnames "$OUTP"_thetasWindows_$WIN3.gz

