#!/bin/bash -l
#SBATCH -J angsd_4fold_sfs_individual_REVISION_01
#SBATCH -o angsd_4fold_sfs_individual_REVISION_01_%j.out
#SBATCH -e angsd_4fold_sfs_individual_REVISION_01_%j.err
#SBATCH -t 10:00:00
#SBATCH -n 1
#SBATCH --nodes=1
#SBATCH --cpus-per-task=4
#SBATCH --mem=16000
#SBATCH -p serial
#SBATCH --array=1-24
#SBATCH --mail-type=END
#SBATCH --mail-user=tiina.mattila@oulu.fi

name=$(sed -n "$SLURM_ARRAY_TASK_ID"p /wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/SUPPORT_FILES/individual_bams)

export PATH=${PATH}:${USERAPPL}/angsd_GIT2/angsd/
export PATH=${PATH}:${USERAPPL}/angsd_GIT2/angsd/misc/

# Set path to sites (not needed if the sites files are in the working directory)
SITES=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/MASKS_010317/AL_1.0.29_4fold_globmasked_CHR.sites

# Set reference (ancestral) path
REF_AL=/wrk/mattitii/DONOTREMOVE/FINAL_ANALYSES/AL_REF/Arabidopsis_lyrata.v.1.0.29.dna.genome.fa

# bam input folder
BAMPATH=/wrk/mattitii/DONOTREMOVE/FINAL_ANALYSES/WGS_alignment_processing_04_0_GATK_IdelRealigner/

# individual bam
IND="$BAMPATH""$name"

# Set output name
OUTP=${name::${#name}-4}_4fold

# Set a file of chromosomes to include
REGIONS=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/SUPPORT_FILES/Chrom.txt

# Set angsd filtering settings
FILTER="-remove_bads -unique_only -minMapQ 30 -minQ 20 -only_proper_pairs 1 -trim 0 -minInd 1"

# Calculate site allele frequency likelihoods (saf)
angsd -i $IND -anc $REF_AL $FILTER -out $OUTP -P 4 -GL 2 -doSaf 1 -sites $SITES -rf $REGIONS

# Estimate allele frequency spectrum
realSFS $OUTP.saf.idx -P 4 > $OUTP.sfs
realSFS $OUTP.saf.idx -P 4 -bootstrap 100 > "$OUTP"_bootstrap.sfs
