#!/bin/bash -l
#SBATCH -J angsd_basic_unfolded_SP_01_REVISION
#SBATCH -o angsd_basic_unfolded_SP_01_REVISION_%j.out
#SBATCH -e angsd_basic_unfolded_SP_01_REVISION_%j.err
#SBATCH -t 20:00:00
#SBATCH -n 1
#SBATCH --nodes=1
#SBATCH --cpus-per-task=4
#SBATCH --mem=40000
#SBATCH -p serial
#SBATCH --array=1-4
#SBATCH --mail-type=END
#SBATCH --mail-user=tiina.mattila@oulu.fi

name=$(sed -n "$SLURM_ARRAY_TASK_ID"p /wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/SUPPORT_FILES/namelist_020317)

export PATH=${PATH}:${USERAPPL}/angsd_GIT2/angsd/
export PATH=${PATH}:${USERAPPL}/angsd_GIT2/angsd/misc/

#Set path to sites (not needed if the sites files are in the working directory)
SITEPATH=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/MASKS_010317/

#Set reference (ancestral) path
REF_AL=/proj/tpyhaja/GENERATE_ANCESTRAL_FASTA/input/Arabidopsis_lyrata.v.1.0.29.dna.genome_ATANC_060317.fa

#name of the file containing list of full paths of bamfiles, one sample/row
SP=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/SUPPORT_FILES/SP_bam.filelist

##Set output name
OUTP=SP_${name::${#name}-6}

##Set sites filter file
SITES=$SITEPATH$name

##Set a file of chromosomes to include
REGIONS=/wrk/mattitii/DONOTREMOVE/FINAL_RESULTS_200217/SUPPORT_FILES/Chrom.txt

##Set angsd filtering settings
FILTER="-remove_bads -unique_only -minMapQ 30 -minQ 20 -only_proper_pairs 1 -trim 0 -minInd 4"

##Calculate site allele frequency likelihoods (saf)
angsd -b $SP -anc $REF_AL $FILTER -out $OUTP -P 4 -GL 2 -doSaf 1 -sites $SITES -rf $REGIONS

##Estimate allele frequency spectrum
realSFS $OUTP.saf.idx -P 4 -bootstrap 100 > "$OUTP"_bootstrap.sfs
realSFS $OUTP.saf.idx -P 4 > $OUTP.sfs

